prettyconf
==========

|Build Status| |Coverage Status| |Docs|

Pretty Conf is a Python library created to make easy the separation of
configuration and code following the recomendations of `12 Factor`_'s topic
about configs.


Documentation
-------------

You can find ``prettyconf`` documentation at `Read the Docs`_ website.


.. _`12 Factor`: http://12factor.net/
.. _`Read the Docs`: http://prettyconf.readthedocs.org/


.. |Build Status| image:: https://travis-ci.org/osantana/prettyconf.png?branch=master
   :target: https://travis-ci.org/osantana/prettyconf
.. |Coverage Status| image:: https://coveralls.io/repos/osantana/prettyconf/badge.svg?branch=master
   :target: https://coveralls.io/r/osantana/prettyconf?branch=master
.. |Docs| image:: https://readthedocs.org/projects/prettyconf/badge/?version=latest
   :target: https://readthedocs.org/projects/prettyconf/?badge=latest
